spacepy.irbempy.car2sph — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »

# spacepy.irbempy.car2sph

`spacepy.irbempy.` `car2sph`(CARin)

  coordinate transformation from cartesian to spherical

  Parameters: | - CARin (list or ndarray) : coordinate points in (n,3) shape with n coordinate points in units of [Re, Re, Re] = [x,y,z]
  Returns: | - results (ndarray) : values after conversion to spherical coordinates in radius, latitude, longitude in units of [Re, deg, deg]

  See also

  `sph2car`

  Examples

      >>> sph2car([1,45,0])
      array([ 0.70710678,  0.        ,  0.70710678])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »